package
Version:
v0.0.0-...-49189e4
Opens a new window with list of versions in this module.
Published: Sep 18, 2025
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Database struct {
DB *sql.DB
}
Database wraps the sql.DB connection and provides helper methods
NewSQLiteDB creates a new SQLite database connection
Close closes the database connection
Health checks if the database connection is healthy
Migration represents a database migration
Source Files
¶
Click to show internal directories.
Click to hide internal directories.